Django Hordak — Django Hordak 1.0 documentation

# Django Hordak

Django Hordak is the core functionality of a double entry accounting system. It provides thoroughly tested core models with relational integrity constrains to ensure consistency.

Hordak also includes a basic accounting interface. This should allow you to get up-and-running quickly. However, the expectation is that you will either heavily build on this example or use one of the interfaces detailed below.

Interfaces which build on Hordak include:

> - battlecat – General purpose accounting interface (work in progress)
> - swiftwind – Accounting for communal households (work in progress)

## Requirements

Hordak is tested against:

> - Django >= 1.8, <= 1.10
> - Python 2.7, 3.4, 3.5, nightly
> - Postgres 9

Postgres is required, MySQL is unsupported. This is due to the database constraints we apply to ensure data integrity. MySQL could be certainly supported in future, volunteers welcome.

Contents:

- Installation
  - Using the interface
  - Using the models
- Getting Started
- Customising Templates
- Double Entry Accounting for Developers
  - Accounting in six bullet points (& three footnotes)
  - In a little more detail
  - Examples
- API Documentation
  - Models
  - Views
  - Forms
  - Money Utilities
  - Currency Utilities
  - Exceptions
- Notes
  - Fixtures
- Hordak Changelog
  - 1.1.0

# Indices and tables

- Index
- Module Index
- Search Page